@@ -1,38 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the QtSerialBus module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL3$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2017 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qcanbusdevice.h"
 #include "qcanbusdevice_p.h"
@@ -49,7 +16,7 @@
 
 QT_BEGIN_NAMESPACE
 
-Q_LOGGING_CATEGORY(QT_CANBUS, "qt.canbus")
+Q_STATIC_LOGGING_CATEGORY(QT_CANBUS, "qt.canbus")
 
 /*!
     \class QCanBusDevice
@@ -150,19 +117,17 @@ Q_LOGGING_CATEGORY(QT_CANBUS, "qt.canbus")
 */
 
 /*!
-    \fn bool operator==(const QCanBusDevice::Filter &a, const QCanBusDevice::Filter &b)
-    \relates QCanBusDevice::Filter
+    \fn bool QCanBusDevice::Filter::operator==(const QCanBusDevice::Filter &a, const QCanBusDevice::Filter &b)
 
-    Returns true, if the filter \a a is equal to the filter \a b,
-    otherwise returns false.
+    Returns \c true, if the filter \a a is equal to the filter \a b,
+    otherwise returns \c false.
 */
 
 /*!
-    \fn bool operator!=(const QCanBusDevice::Filter &a, const QCanBusDevice::Filter &b)
-    \relates QCanBusDevice::Filter
+    \fn bool QCanBusDevice::Filter::operator!=(const QCanBusDevice::Filter &a, const QCanBusDevice::Filter &b)
 
-    Returns true, if the filter \a a is not equal to the filter \a b,
-    otherwise returns false.
+    Returns \c true, if the filter \a a is not equal to the filter \a b,
+    otherwise returns \c false.
 */
 
 /*!
@@ -293,7 +258,7 @@ void QCanBusDevice::clearError()
     Subclasses must call this function when they receive frames.
 
 */
-void QCanBusDevice::enqueueReceivedFrames(const QVector<QCanBusFrame> &newFrames)
+void QCanBusDevice::enqueueReceivedFrames(const QList<QCanBusFrame> &newFrames)
 {
     Q_D(QCanBusDevice);
 
@@ -344,30 +309,6 @@ bool QCanBusDevice::hasOutgoingFrames() const
     return !d->outgoingFrames.isEmpty();
 }
 
-/*!
- * \since 5.14
- * Called from the derived plugin to register a function \a resetter which performs the
- * CAN controller hardware reset when resetController() is called.
- */
-void QCanBusDevice::setResetControllerFunction(std::function<void()> resetter)
-{
-    Q_D(QCanBusDevice);
-
-    d->m_resetControllerFunction = std::move(resetter);
-}
-
-/*!
- * \since 5.14
- * Called from the derived plugin to register a function \a busStatusGetter
- * which returns the CAN controller bus status when busStatus() is called.
- */
-void QCanBusDevice::setCanBusStatusGetter(std::function<CanBusStatus()> busStatusGetter)
-{
-    Q_D(QCanBusDevice);
-
-    d->m_busStatusGetter = std::move(busStatusGetter);
-}
-
 /*!
     Sets the configuration parameter \a key for the CAN bus connection
     to \a value. The potential keys are represented by \l ConfigurationKey.
@@ -381,7 +322,7 @@ void QCanBusDevice::setCanBusStatusGetter(std::function<CanBusStatus()> busStatu
 
     \sa configurationParameter()
 */
-void QCanBusDevice::setConfigurationParameter(int key, const QVariant &value)
+void QCanBusDevice::setConfigurationParameter(ConfigurationKey key, const QVariant &value)
 {
     Q_D(QCanBusDevice);
 
@@ -411,7 +352,7 @@ void QCanBusDevice::setConfigurationParameter(int key, const QVariant &value)
 
     \sa setConfigurationParameter(), configurationKeys()
 */
-QVariant QCanBusDevice::configurationParameter(int key) const
+QVariant QCanBusDevice::configurationParameter(ConfigurationKey key) const
 {
     Q_D(const QCanBusDevice);
 
@@ -426,15 +367,15 @@ QVariant QCanBusDevice::configurationParameter(int key) const
 /*!
     Returns the list of keys used by the CAN bus connection.
 
-    The the meaning of the keys is equivalent to \l ConfigurationKey.
-    If a key is not explicitly mentioned the platform's
+    The meaning of the keys is equivalent to \l ConfigurationKey.
+    If a key is not explicitly mentioned, the platform's
     default setting for the relevant key is used.
 */
-QVector<int> QCanBusDevice::configurationKeys() const
+QList<QCanBusDevice::ConfigurationKey> QCanBusDevice::configurationKeys() const
 {
     Q_D(const QCanBusDevice);
 
-    QVector<int> result;
+    QList<ConfigurationKey> result;
     for (const ConfigEntry &e : d->configOptions)
         result.append(e.first);
 
@@ -510,14 +451,10 @@ qint64 QCanBusDevice::framesToWrite() const
 */
 void QCanBusDevice::resetController()
 {
-    if (d_func()->m_resetControllerFunction) {
-        d_func()->m_resetControllerFunction();
-    } else {
-        const char error[] = QT_TRANSLATE_NOOP("QCanBusDevice",
-                "This CAN bus plugin does not support hardware controller reset.");
-        qCWarning(QT_CANBUS, error);
-        setError(tr(error), QCanBusDevice::CanBusError::ConfigurationError);
-    }
+    const char error[] = QT_TRANSLATE_NOOP("QCanBusDevice",
+            "This CAN bus plugin does not support hardware controller reset.");
+    qCWarning(QT_CANBUS, error);
+    setError(tr(error), QCanBusDevice::CanBusError::ConfigurationError);
 }
 
 /*!
@@ -529,7 +466,7 @@ void QCanBusDevice::resetController()
  */
 bool QCanBusDevice::hasBusStatus() const
 {
-    return d_func()->m_busStatusGetter != nullptr;
+    return false;
 }
 
 /*!
@@ -561,11 +498,8 @@ bool QCanBusDevice::hasBusStatus() const
 
     \sa hasBusStatus(), resetController()
 */
-QCanBusDevice::CanBusStatus QCanBusDevice::busStatus() const
+QCanBusDevice::CanBusStatus QCanBusDevice::busStatus()
 {
-    if (d_func()->m_busStatusGetter)
-        return d_func()->m_busStatusGetter();
-
     return QCanBusDevice::CanBusStatus::Unknown;
 }
 
@@ -816,13 +750,13 @@ QCanBusFrame QCanBusDevice::readFrame()
 /*!
     \since 5.12
     Returns all \l{QCanBusFrame}s from the queue; otherwise returns
-    an empty QVector. The returned frames are removed from the queue.
+    an empty QList. The returned frames are removed from the queue.
 
     The queue operates according to the FIFO principle.
 
     \sa clear(), framesAvailable(), readFrame()
 */
-QVector<QCanBusFrame> QCanBusDevice::readAllFrames()
+QList<QCanBusFrame> QCanBusDevice::readAllFrames()
 {
     Q_D(QCanBusDevice);
 
@@ -830,14 +764,14 @@ QVector<QCanBusFrame> QCanBusDevice::readAllFrames()
         const QString error = tr("Cannot read frame as device is not connected.");
         qCWarning(QT_CANBUS, "%ls", qUtf16Printable(error));
         setError(error, CanBusError::OperationError);
-        return QVector<QCanBusFrame>();
+        return QList<QCanBusFrame>();
     }
 
     clearError();
 
     QMutexLocker locker(&d->incomingFramesGuard);
 
-    QVector<QCanBusFrame> result;
+    QList<QCanBusFrame> result;
     result.swap(d->incomingFrames);
     return result;
 }
@@ -977,35 +911,57 @@ void QCanBusDevice::setState(QCanBusDevice::CanBusDeviceState newState)
 }
 
 /*!
- * Returns a QCanBusDeviceInfo created from the given parameters \a name,
- * \a isVirtual, and \a isFlexibleDataRateCapable.
+ * \since 6.2
+ * Returns a QCanBusDeviceInfo created from the given parameters \a plugin,
+ * \a name, \a isVirtual, and \a isFlexibleDataRateCapable.
  * \internal
  */
-QCanBusDeviceInfo QCanBusDevice::createDeviceInfo(const QString &name, bool isVirtual,
+QCanBusDeviceInfo QCanBusDevice::createDeviceInfo(const QString &plugin, const QString &name,
+                                                  bool isVirtual,
                                                   bool isFlexibleDataRateCapable)
 {
-    return createDeviceInfo(name, QString(), QString(), 0, isVirtual, isFlexibleDataRateCapable);
+    return createDeviceInfo(plugin, name, QString(), QString(), QString(),
+                            0, isVirtual, isFlexibleDataRateCapable);
 }
 
 /*!
-    \since 5.11
-    Returns a QCanBusDeviceInfo created from the given parameters \a name,
-    \a serialNumber, \a description, \a channel, \a isVirtual, and \a
-    isFlexibleDataRateCapable.
+    \since 6.2
+    Returns a QCanBusDeviceInfo created from the given parameters \a plugin,
+    \a name, \a serialNumber, \a description, \a alias, \a channel, \a isVirtual,
+    and \a isFlexibleDataRateCapable.
     \internal
  */
-QCanBusDeviceInfo QCanBusDevice::createDeviceInfo(const QString &name, const QString &serialNumber,
-                                                  const QString &description, int channel,
-                                                  bool isVirtual, bool isFlexibleDataRateCapable)
+QCanBusDeviceInfo QCanBusDevice::createDeviceInfo(const QString &plugin,
+                                                  const QString &name,
+                                                  const QString &serialNumber,
+                                                  const QString &description,
+                                                  const QString &alias,
+                                                  int channel,
+                                                  bool isVirtual,
+                                                  bool isFlexibleDataRateCapable)
 {
-    QScopedPointer<QCanBusDeviceInfoPrivate> info(new QCanBusDeviceInfoPrivate);
+    std::unique_ptr<QCanBusDeviceInfoPrivate> info(new QCanBusDeviceInfoPrivate);
+    info->plugin = plugin;
     info->name = name;
     info->serialNumber = serialNumber;
     info->description = description;
+    info->alias = alias;
     info->channel = channel;
     info->hasFlexibleDataRate = isFlexibleDataRateCapable;
     info->isVirtual = isVirtual;
-    return QCanBusDeviceInfo(*info.take());
+    return QCanBusDeviceInfo(*info.release());
+}
+
+/*!
+    \since 6.2
+
+    Returns a QCanBusDeviceInfo for the current QCanBusDevice. If the function
+    is not implemented by a sub-class of QCanBusDevice, a default constructed
+    object is returned.
+ */
+QCanBusDeviceInfo QCanBusDevice::deviceInfo() const
+{
+    return QCanBusDeviceInfo(*(new QCanBusDeviceInfoPrivate));
 }
 
 QT_END_NAMESPACE
